<template>
  <div class="card" style="width: 100%">
    <div class="card-body">
      <div class="mb-3">
        <h4
          class="card-title"
          :class="$i18n.locale == 'ar' ? 'font-size-15' : ''"
        >
          {{ $t("app.user_in_system") }}
        </h4>

        <select
          class="form-control"
          :class="$i18n.locale == 'ar' ? 'font-size-15' : ''"
          v-model="row.user_in_system"
          v-on:change="onInputChange"
        >
          <option value="1">
            {{ $t("app.yes") }}
          </option>
          <option value="0">
            {{ $t("app.no") }}
          </option>
        </select>
      </div>

      <div class="mb-3" v-if="row.user_in_system == '1'">
        <h4
          class="card-title"
          :class="$i18n.locale == 'ar' ? 'font-size-15' : ''"
        >
          {{ $t("app.choose_user") }}
        </h4>
        <div class="col-md-12 text-center" style="padding: 0">
          <span
            v-if="userLoading"
            class="spinner-grow spinner-grow-sm mr-1"
            role="status"
            aria-hidden="true"
          >
          </span>
          <select
            v-if="!userLoading"
            id="users"
            class="form-control"
            :class="$i18n.locale == 'ar' ? 'font-size-15' : ''"
            v-model="row.user_id"
            v-on:change="onInputChange"
          >
            <option v-for="(row, idx) in users" :key="idx" :value="row.id">
              {{ row.name }}
            </option>
          </select>
        </div>
      </div>

      <FormClient
        v-else-if="row.user_in_system == '0'"
        v-on:userChanged="userChanged"
      >
      </FormClient>

      <CardInvoiceSocial
        @sendInvoiceChange="handleSendInvoiceChange"
        v-if="hasSendInvoice"
        :sendInvoice="sendInvoice"
      />
    </div>
  </div>
</template>

<script>
import iziToast from "izitoast";
import FormClient from "@/components/FormClient";
import CardInvoiceSocial from "@/components/CardInvoiceSocial";

export default {
  name: "CardUser",
  components: {
    CardInvoiceSocial,
    FormClient,
  },
  props: ["user_id", "userInSystem", "hasSendInvoice", "sendInvoice"],
  data() {
    return {
      auth: {
        id_token: "",
      },
      row: {
        user_id: this.$props.user_id,
        user_in_system: this.$props.userInSystem,
      },
      users: [],
      userLoading: true,
    };
  },
  created() {
    if (localStorage.getItem("id_token")) {
      this.auth.id_token = localStorage.getItem("id_token");
    }

    this.fetchData();
  },
  methods: {
    onInputChange() {
      const data = {
        input: this.row.user_id,
        user_in_system: this.row.user_in_system,
      };
      this.$emit("userChange", data);
    },

    fetchData() {
      this.userLoading = true;
      this.axios.defaults.headers.common = {
        "X-Requested-With": "XMLHttpRequest", // security to prevent CSRF attacks
        Authorization: `Bearer ` + this.auth.id_token,
      };
      const options = {
        url: "/users",
        method: "GET",
        data: {},
        params: {
          status: 1,
          suspend: 0,
          role: "member",
          paginate: 1000,
        },
      };
      this.axios(options)
        .then((res) => {
          this.userLoading = false;
          this.users = res.data.data.rows;
        })
        .catch((err) => {
          this.userLoading = false;
          iziToast.warning({
            icon: "bx bx-angry",
            title: "",
            message: err.response ? err.response.data.message : "" + err,
          });
        });
    },
    userChanged(event) {
      this.$emit("clientChange", event);
    },
    handleSendInvoiceChange(event) {
      this.$emit("sendInvoiceChange", event);
    },
  },
};
</script>
